@@ -326,7 +326,7 @@ task {{task.tjp_id}} "{{task.name}}" {
         {%- endif %}
         {% for time_log in task.time_logs %}
             booking {{time_log.resource.tjp_id}} {{time_log.start.strftime('%Y-%m-%d-%H:%M:%S')}} - {{time_log.end.strftime('%Y-%m-%d-%H:%M:%S')}} { overtime 2 }
-        {%- endfor %}
+        {% endfor %}
     {% endif %}
 
 }
@@ -374,10 +374,33 @@ resource {{department.tjp_id}} "{{department.name}}" {
         taskreport breakdown "{{csv_file_full_path}}"{
             formats csv
             timeformat "%Y-%m-%d-%H:%M"
-            columns id, start, end, resources
+            columns id, start, end {%- if compute_resources %}, resources{% endif %}
         }
         """,
 
+        tjp_main_template2="""# Generated By Stalker v{{stalker.__version__}}
+        {{studio.to_tjp}}
+
+        # resources
+        resource resources "Resources" {
+        {%- for vacation in studio.vacations %}
+            {{vacation.to_tjp}}
+        {%- endfor %}
+        {%- for user in studio.users %}
+            {{user.to_tjp}}
+        {%- endfor %}
+        }
+
+# tasks
+{{ tasks_buffer }}
+
+# reports
+taskreport breakdown "{{csv_file_full_path}}"{
+    formats csv
+    timeformat "%Y-%m-%d-%H:%M"
+    columns id, start, end {%- if compute_resources %}, resources{% endif %}
+}""",
+
         tj_command='/usr/local/bin/tj3',
 
         path_template='{{project.code}}/{%- for parent_task in parent_tasks -%}{{parent_task.nice_name}}/{%- endfor -%}',
